@@ -6,7 +6,7 @@ use 5.008001;
 use Carp ();
 
 # ABSTRACT: Alien::Build logging
-our $VERSION = '1.80_01'; # TRIAL VERSION
+our $VERSION = '1.81_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -31,7 +31,7 @@ sub default
       $pm =~ s/::/\//g;
       require $pm;
     }
-    $self = bless {}, $class;
+    $class->new;
   }
 }
 
@@ -64,7 +64,7 @@ Alien::Build::Log - Alien::Build logging
 
 =head1 VERSION
 
-version 1.80_01
+version 1.81_01
 
 =head1 SYNOPSIS
 
