@@ -6,10 +6,10 @@ use 5.008001;
 use Term::ANSIColor ();
 use Path::Tiny qw( path );
 use File::chdir;
-use base qw( Alien::Build );
+use base qw( Alien::Build::Log );
 
 # ABSTRACT: Log class for Alien::Build which is less verbose
-our $VERSION = '1.80_01'; # TRIAL VERSION
+our $VERSION = '1.81_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -66,7 +66,7 @@ Alien::Build::Log::Abbreviate - Log class for Alien::Build which is less verbose
 
 =head1 VERSION
 
-version 1.80_01
+version 1.81_01
 
 =head1 SYNOPSIS
 
